==> qtjambi-qt3dcore-5.15-sources.jar: io/qt/qt3d/core/QAbstractSkeleton.java <==
package io.qt.qt3d.core;


/**
 * <p>A skeleton contains the joints for a skinned mesh</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qabstractskeleton.html">Qt3DCore::QAbstractSkeleton</a></p>
 */
public class QAbstractSkeleton extends io.qt.qt3d.core.QNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractSkeleton.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::jointCountChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="jointCount")
    public final Signal1<@io.qt.QtPrimitiveType Integer> jointCountChanged = new Signal1<>();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::jointCount()const</a></p>
     */
    @io.qt.QtPropertyReader(name="jointCount")
    @io.qt.QtUninvokable
    public final int jointCount(){
        return jointCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int jointCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractSkeleton(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QAbstractSkeleton.java <==
package io.qt.qt3d.core;


/**
 * <p>A skeleton contains the joints for a skinned mesh</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qabstractskeleton.html">Qt3DCore::QAbstractSkeleton</a></p>
 */
public class QAbstractSkeleton extends io.qt.qt3d.core.QNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractSkeleton.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::jointCountChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="jointCount")
    public final Signal1<@io.qt.QtPrimitiveType Integer> jointCountChanged = new Signal1<>();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::jointCount()const</a></p>
     */
    @io.qt.QtPropertyReader(name="jointCount")
    @io.qt.QtUninvokable
    public final int jointCount(){
        return jointCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int jointCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractSkeleton(QPrivateConstructor p) { super(p); } 
    
}
